@@ -5,7 +5,7 @@ from clld_morphology_plugin import datatables
 
 __author__ = "Florian Matter"
 __email__ = "florianmatter@gmail.com"
-__version__ = "0.0.2"
+__version__ = "0.0.3"
 
 
 def includeme(config):
@@ -27,10 +27,12 @@ def includeme(config):
     config.register_resource(
         "meaning", models.Meaning, interfaces.IMeaning, with_index=True
     )
+    config.register_resource("pos", models.POS, interfaces.IPOS, with_index=True)
     config.register_resource(
         "wordform", models.Wordform, interfaces.IWordform, with_index=True
     )
 
+    config.register_datatable("pos", datatables.POS)
     config.register_datatable("meanings", datatables.Meanings)
     config.register_datatable("morphs", datatables.Morphs)
     config.register_datatable("wordforms", datatables.Wordforms)
