@@ -23,3 +23,9 @@ class IWordform(Interface):
     """
     form interface
     """
+
+
+class IPOS(Interface):
+    """
+    part of speech interface
+    """
