@@ -12,7 +12,7 @@ from sqlalchemy import UniqueConstraint
 from sqlalchemy.orm import relationship
 from zope.interface import implementer
 from clld_morphology_plugin.interfaces import IMeaning
-from clld_morphology_plugin.interfaces import IMorph
+from clld_morphology_plugin.interfaces import IMorph, IPOS
 from clld_morphology_plugin.interfaces import IMorphset
 from clld_morphology_plugin.interfaces import IWordform
 
@@ -53,8 +53,16 @@ class MorphemeMeaning(Base):
     morpheme = relationship(Morpheme, innerjoin=True, backref="meanings")
     meaning = relationship(Meaning, innerjoin=True, backref="morphemes")
 
+
+@implementer(IPOS)
+class POS(Base, IdNameDescriptionMixin):
+    pass
+
+
 @implementer(IWordform)
-class Wordform(Base, PolymorphicBaseMixin, IdNameDescriptionMixin, HasSourceMixin, HasFilesMixin):
+class Wordform(
+    Base, PolymorphicBaseMixin, IdNameDescriptionMixin, HasSourceMixin, HasFilesMixin
+):
     __table_args__ = (UniqueConstraint("language_pk", "id"),)
 
     language_pk = Column(Integer, ForeignKey("language.pk"), nullable=False)
@@ -63,14 +71,18 @@ class Wordform(Base, PolymorphicBaseMixin, IdNameDescriptionMixin, HasSourceMixi
     contribution_pk = Column(Integer, ForeignKey("contribution.pk"))
     contribution = relationship(Contribution, backref="wordforms")
 
+    pos_pk = Column(Integer, ForeignKey("pos.pk"))
+    pos = relationship(POS, backref="wordforms")
+
     segmented = Column(String)
 
     @property
     def audio(self):
         for f in self._files:
-            if f.mime_type.split('/')[0] == 'audio':
+            if f.mime_type.split("/")[0] == "audio":
                 return f
-                
+
+
 class FormMeaning(Base):
     id = Column(String, unique=True)
     form_pk = Column(Integer, ForeignKey("wordform.pk"), nullable=False)
@@ -78,6 +90,7 @@ class FormMeaning(Base):
     form = relationship(Wordform, innerjoin=True, backref="meanings")
     meaning = relationship(Meaning, innerjoin=True, backref="forms")
 
+
 class FormSlice(Base):
     form_pk = Column(Integer, ForeignKey("wordform.pk"))
     morph_pk = Column(Integer, ForeignKey("morph.pk"))
@@ -89,5 +102,6 @@ class FormSlice(Base):
     form_meaning = relationship(FormMeaning)
     morpheme_meaning = relationship(MorphemeMeaning, backref="morph_tokens")
 
+
 class Wordform_files(Base, FilesMixin):
-    pass
\ No newline at end of file
+    pass
