@@ -14,25 +14,27 @@ def rendered_gloss_units(request, sentence):
     if sentence.analyzed and sentence.gloss:
         # g-words associated with this sentence
         slices = {sl.index: sl for sl in sentence.forms}
-        g_shift = 0 # to keep up to date with how many g-words there are in total
+        g_shift = 0  # to keep up to date with how many g-words there are in total
         for pwc, (pword, pgloss) in enumerate(
             zip(sentence.analyzed.split("\t"), sentence.gloss.split("\t"))
         ):
             g_words = []
             morphs = []
             glosses = []
+            posses = []
             for gwc, (word, gloss) in enumerate(
                 zip(pword.split("="), pgloss.split("="))
             ):
                 i = pwc + gwc + g_shift
                 if gwc > 0:
                     g_shift += 1
-                    for glosslist in [g_words, morphs, glosses]:
+                    for glosslist in [g_words, morphs, glosses, posses]:
                         glosslist.append("=")
                 if i not in slices:
                     g_words.append(HTML.span(word))
                     morphs.append(HTML.span(word, class_="morpheme"))
                     glosses.append(HTML.span(gloss))
+                    posses.append(HTML.span("?"))
                 else:
                     g_words.append(
                         HTML.span(
@@ -41,20 +43,28 @@ def rendered_gloss_units(request, sentence):
                         )
                     )
                     morphs.append(
-                        HTML.span(
-                            rendered_form(request, slices[i]),
-                            class_="morpheme",
-                        )
+                        HTML.span(rendered_form(request, slices[i]), class_="morpheme")
                     )
                     glosses.append(HTML.span(gloss, **{"class": "gloss"}))
+                    if slices[i].form.pos:
+                        posses.append(
+                            HTML.span(
+                                link(
+                                    request,
+                                    slices[i].form.pos,
+                                    label=slices[i].form.pos.id,
+                                ),
+                                **{"class": "pos"},
+                            )
+                        )
+                    else:
+                        posses.append(HTML.span("?"))
             units.append(
                 HTML.div(
                     HTML.div(*g_words),
-                    HTML.div(
-                        *morphs,
-                        class_="morpheme",
-                    ),
+                    HTML.div(*morphs, class_="morpheme"),
                     HTML.div(*glosses, **{"class": "gloss"}),
+                    HTML.div(*posses),
                     class_="gloss-unit",
                 )
             )
@@ -70,11 +80,15 @@ def rendered_form(request, example_slice, structure=True):
                     [
                         link(
                             request,
-                            form_slice.morph,
+                            form_slice.morph.morpheme,
                             label=form_slice.morph.name.strip("-"),
-                            name=form_slice.morph.id+"-"+form_slice.morpheme_meaning.id,
+                            name=form_slice.morph.id
+                            + "-"
+                            + form_slice.morpheme_meaning.id,
                         )
-                        for form_slice in form.morphs if form_slice.form_meaning.meaning == example_slice.form_meaning.meaning
+                        for form_slice in form.morphs
+                        if form_slice.form_meaning.meaning
+                        == example_slice.form_meaning.meaning
                     ]
                 )
             )
